Changelog
=========

0.0.4 (2024-02-27)
------------------

- extended text generation interface to keep track of inputs and #turns (*history*);
  added support for JSON responses; field name in JSON prompt is now customizable


0.0.3 (2024-02-15)
------------------

- added interface for text classification


0.0.2 (2023-11-12)
------------------

- title and description used in the interface are now customizable via the `--title`
  and `--description` command-line options


0.0.1 (2023-11-03)
------------------

- initial release

